export HTTPS_PROXY=https://www-proxy.us.oracle.com:80
export HTTP_PROXY=https://www-proxy.us.oracle.com:80
export https_proxy=https://www-proxy.us.oracle.com:80
export http_proxy=https://www-proxy.us.oracle.com:80
