#!/bin/bash

export TF_VAR_client_image=`grep image.oc ./ciout | awk -e '{ print $2 }' | sed 's/"//g' | sed 's/,//g'`

terraform plan -target=oci_core_instance.clientimage -out ./ciplan
terraform apply ./ciplan
