#!/bin/bash

rm ./ciout
terraform init

terraform plan -target=oci_core_instance.AlphaDB01 -target=oci_core_instance.AlphaDB02 -target=oci_core_instance.AlphaMW01 -target=oci_core_instance.AlphaMW02 -target=null_resource.client_image -target=oci_load_balancer.lb1 -target=oci_load_balancer_backendset.lb-bes1 -target=oci_load_balancer_certificate.lb-cert1 -target=oci_load_balancer_listener.lb-listener1 -target=oci_load_balancer_listener.lb-listener2 -target=oci_load_balancer_backend.lb-be1 -target=oci_load_balancer_backend.lb-be2 -out ./infraplan

terraform apply ./infraplan
