#!/bin/bash

oci compute image import from-object-uri --compartment-id ocid1.compartment.oc1..aaaaaaaa2xw22gapoakgxo5lxou6bjka6jupib4xwkj2ykknkv2ehskylyda --display-name ClientImageV32 --launch-mode EMULATED --uri https://objectstorage.us-ashburn-1.oraclecloud.com/p/kRDEBbp4G02BMNUBOeX4MS1Yk4Ldalgnxm8rLb-Sjg0/n/gse00014344/b/demo_import/o/OL74OCI_ClientimageV32_withOCIkey --source-image-type QCOW2 > ./ciout

sleep 1680
