require 'oci'

my_config = OCI::ConfigFileLoader.load_config(config_file_location:'./.oci/config', profile_name:'DEFAULT')
api = OCI::Identity::IdentityClient.new(config:my_config)
response = api.get_user(my_config.user)
puts 'User Name: ' + response.data.name
