ssh-keygen -b 2048 -t rsa -f oci_instance_key
openssl genrsa -out oci_api_key.pem 2048 
chmod 0600 oci_api_key.pem
openssl rsa -pubout -in oci_api_key.pem -out oci_api_key_public.pem
openssl rsa -pubout -outform DER -in oci_api_key.pem | openssl md5 -c
chmod 0600 oci_*
